==> gcc-3.3.4.tar.bz2: gcc-3.3.4/libjava/javax/transaction/Transaction.java <==
/* Transaction.java -- 
   Copyright (C) 2001, 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.transaction;

import javax.transaction.xa.XAResource;
 
/**
 * @author Warren Levy <warrenl@redhat.com>
 * @date May 25, 2001
 */

public interface Transaction
{
  public void commit()
    throws RollbackException, HeuristicMixedException,
      HeuristicRollbackException, SecurityException, SystemException;

  public boolean delistResource(XAResource xaRes, int flag)
    throws IllegalStateException, SystemException;

  public boolean enlistResource(XAResource xaRes)
    throws RollbackException, IllegalStateException, SystemException;

  public int getStatus() throws SystemException;

  public void registerSynchronization(Synchronization sync)
    throws RollbackException, IllegalStateException, SystemException;

  public void rollback()
    throws IllegalStateException, SystemException;

  public void setRollbackOnly()
    throws IllegalStateException, SystemException;
}

==> gcc-3.4.6.tar.bz2: gcc-3.4.6/libjava/javax/transaction/Transaction.java <==
/* Transaction.java -- 
   Copyright (C) 2001, 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.transaction;

import javax.transaction.xa.XAResource;
 
/**
 * @author Warren Levy <warrenl@redhat.com>
 * @date May 25, 2001
 */

public interface Transaction
{
  void commit()
    throws RollbackException, HeuristicMixedException,
      HeuristicRollbackException, SecurityException, SystemException;

  boolean delistResource(XAResource xaRes, int flag)
    throws IllegalStateException, SystemException;

  boolean enlistResource(XAResource xaRes)
    throws RollbackException, IllegalStateException, SystemException;

  int getStatus() throws SystemException;

  void registerSynchronization(Synchronization sync)
    throws RollbackException, IllegalStateException, SystemException;

  void rollback()
    throws IllegalStateException, SystemException;

  void setRollbackOnly()
    throws IllegalStateException, SystemException;
}
